@@ -1,17 +1,10 @@
-
-require 5;
 package Pod::Perldoc::ToRtf;
 use strict;
 use warnings;
+use parent qw( Pod::Simple::RTF );
+
 use vars qw($VERSION);
-
-use base qw( Pod::Simple::RTF );
-
-$VERSION   # so that ->VERSION is happy
-# stop CPAN from seeing this
- =
-$Pod::Simple::RTF::VERSION;
-
+$VERSION = '3.16';
 
 sub is_pageable        { 0 }
 sub write_with_binmode { 0 }
@@ -20,11 +13,11 @@ sub output_extension   { 'rtf' }
 sub page_for_perldoc {
   my($self, $tempfile, $perldoc) = @_;
   return unless $perldoc->IS_MSWin32;
-  
+
   my $rtf_pager = $ENV{'RTFREADER'} || 'write.exe';
-  
+
   $perldoc->aside( "About to launch <\"$rtf_pager\" \"$tempfile\">\n" );
-  
+
   return 1 if system( qq{"$rtf_pager"}, qq{"$tempfile"} ) == 0;
   return 0;
 }
@@ -52,8 +45,11 @@ You have to have Pod::Simple::RTF installed (from the Pod::Simple dist),
 or this module won't work.
 
 If Perldoc is running under MSWin and uses this class as a formatter,
-the output will be opened with F<write.exe> or whatever program
-is specified in the environment variable C<RTFREADER>.
+the output will be opened with F<write.exe> or whatever program is
+specified in the environment variable C<RTFREADER>. For example, to
+specify that RTF files should be opened the same as they are when you
+double-click them, you would do C<set RTFREADER=start.exe> in your
+F<autoexec.bat>.
 
 Handy tip: put C<set PERLDOC=-ortf> in your F<autoexec.bat>
 and that will set this class as the default formatter to run when
@@ -76,7 +72,12 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Sean M. Burke C<sburke@cpan.org>
+Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
+
+Past contributions from:
+brian d foy C<< <bdfoy@cpan.org> >>
+Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
+Sean M. Burke C<< <sburke@cpan.org> >>
 
 =cut
 
